@@ -270,6 +270,7 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 			xc->pan.surround = 0;
 		}
 		xc->rpv = 0;	/* storlek_20: set pan overrides random pan */
+		xc->pan.surround = 0;
 		break;
 	case FX_OFFSET:		/* Set sample offset */
 		EFFECT_MEMORY(fxp, xc->offset.memory);
@@ -392,12 +393,8 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 			set_lfo_waveform(&xc->vibrato.lfo, fxp);
 			break;
 		case EX_FINETUNE:	/* Set finetune */
-			fxp <<= 4;
-			if (HAS_QUIRK(QUIRK_PROTRACK)) {
-				fxp -= 0x80;
-			}
 			if (!HAS_QUIRK(QUIRK_FT2BUGS) || note > 0) {
-				goto fx_finetune;
+				xc->finetune = (int8)(fxp << 4);
 			}
 			break;
 		case EX_PATTERN_LOOP:	/* Loop pattern */
@@ -465,7 +462,6 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 		break;
 
 	case FX_FINETUNE:
-	      fx_finetune:
 		xc->finetune = (int16) (fxp - 0x80);
 		break;
 
@@ -542,7 +538,7 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 	case FX_IT_ROWDELAY:
 		if (!f->rowdelay_set) {
 			f->rowdelay = fxp;
-			f->rowdelay_set = 1;
+			f->rowdelay_set = 3;
 		}
 		break;
 
@@ -705,6 +701,9 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 			break;
 		}
 		break;
+	case FX_SURROUND:
+		xc->pan.surround = fxp;
+		break;
 
 #ifndef LIBXMP_CORE_DISABLE_IT
 	case FX_TRK_VOL:	/* Track volume setting */
@@ -816,9 +815,6 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 		xc->offset.val &= 0xffff;
 		xc->offset.val |= fxp << 16;
 		break;
-	case FX_SURROUND:
-		xc->pan.surround = fxp;
-		break;
 #endif
 
 #ifndef LIBXMP_CORE_PLAYER
