@@ -96,23 +96,19 @@ int period_to_note(int p)
 
 
 /* Get pitchbend from base note and amiga period */
-int period_to_bend(double p, int n, int gliss, int type, double adj)
+int period_to_bend(double p, int n, int type, double adj)
 {
-    int b;
     double d;
 
     if (n == 0)
 	return 0;
 
     if (type) {
-    	b = 100 * (8 * (((240 - n) << 4) - p));	/* Linear */
-    	return gliss ? b / 12800 * 12800 : b;
+    	return 100 * (8 * (((240 - n) << 4) - p));	/* Linear */
     }
 
     d = note_to_period(n, 0, 0, adj);
-    b = round(100.0 * ((1536.0 * log(d / p) / M_LN2)));
-
-    return gliss ? b / 12800 * 12800 : b;	/* Amiga */
+    return round(100.0 * ((1536.0 * log(d / p) / M_LN2)));	/* Amiga */
 }
 
 
